/*****************************************************************************
 * SASload_NASS_2019_Supplemental.SAS
 * This program will load the NASS 2019 Supplemental csv File into SAS.
 *****************************************************************************/

/* Create SAS informats for missing values */
PROC FORMAT;
  INVALUE N2PF
    '-9' = .
    '-8' = .A
    '-6' = .C
    '-5' = .N
    OTHER = (|2.|)
  ;
  INVALUE N3PF
    '-99' = .
    '-88' = .A
    '-66' = .C
    OTHER = (|3.|)
  ;
  INVALUE N4PF
    '-999' = .
    '-888' = .A
    '-666' = .C
    OTHER = (|4.|)
  ;
  INVALUE N4P1F
    '-9.9' = .
    '-8.8' = .A
    '-6.6' = .C
    OTHER = (|4.1|)
  ;
  INVALUE N5PF
    '-9999' = .
    '-8888' = .A
    '-6666' = .C
    OTHER = (|5.|)
  ;
  INVALUE N5P2F
    '-9.99' = .
    '-8.88' = .A
    '-6.66' = .C
    OTHER = (|5.2|)
  ;
  INVALUE N6PF
    '-99999' = .
    '-88888' = .A
    '-66666' = .C
    OTHER = (|6.|)
  ;
  INVALUE N6P2F
    '-99.99' = .
    '-88.88' = .A
    '-66.66' = .C
    OTHER = (|6.2|)
  ;
  INVALUE N7P2F
    '-999.99' = .
    '-888.88' = .A
    '-666.66' = .C
    OTHER = (|7.2|)
  ;
  INVALUE N8PF
    '-9999999' = .
    '-8888888' = .A
    '-6666666' = .C
    OTHER = (|8.|)
  ;
  INVALUE N8P2F
    '-9999.99' = .
    '-8888.88' = .A
    '-6666.66' = .C
    OTHER = (|8.2|)
  ;
  INVALUE N8P4F
    '-99.9999' = .
    '-88.8888' = .A
    '-66.6666' = .C
    OTHER = (|8.4|)
  ;
  INVALUE N10PF
    '-999999999' = .
    '-888888888' = .A
    '-666666666' = .C
    OTHER = (|10.|)
  ;
  INVALUE N10P4F
    '-9999.9999' = .
    '-8888.8888' = .A
    '-6666.6666' = .C
    OTHER = (|10.4|)
  ;
  INVALUE N10P5F
    '-999.99999' = .
    '-888.88888' = .A
    '-666.66666' = .C
    OTHER = (|10.5|)
  ;
  INVALUE DATE10F
    '-999999999' = .
    '-888888888' = .A
    '-666666666' = .C
    OTHER = (|MMDDYY10.|)
  ;
  INVALUE N11P7F
    '-99.9999999' = .
    '-88.8888888' = .A
    '-66.6666666' = .C
    OTHER = (|11.7|)
  ;
  INVALUE N12P2F
    '-99999999.99' = .
    '-88888888.88' = .A
    '-66666666.66' = .C
    OTHER = (|12.2|)
  ;
  INVALUE N12P5F
    '-99999.99999' = .
    '-88888.88888' = .A
    '-66666.66666' = .C
    OTHER = (|12.5|)
  ;
  INVALUE N13PF
    '-999999999999' = .
    '-888888888888' = .A
    '-666666666666' = .C
    OTHER = (|13.|)
  ;
  INVALUE N15P2F
    '-99999999999.99' = .
    '-88888888888.88' = .A
    '-66666666666.66' = .C
    OTHER = (|15.2|)
  ;
RUN;

/* Data Step to load the file */
DATA Supplemental; 
INFILE 'Supplemental.csv' dsd dlm=',' LRECL = 354;

/* Define data element attributes */
ATTRIB 
  HOSP_NASS                  LENGTH=4
  LABEL="NASS Hospital Number"

  KEY_NASS                   LENGTH=5            FORMAT=8.
  LABEL="NASS record number"

  YEAR                       LENGTH=8
  LABEL="Data Year"

  NCPT_NOTINSCOPE            LENGTH=8
  LABEL="# Out-of-scope CPTs for this encounter"

  CPTCCS1                    LENGTH=4
  LABEL="CPT 1 Procedure CCS"

  CPTCCS2                    LENGTH=4
  LABEL="CPT 2 Procedure CCS"

  CPTCCS3                    LENGTH=4
  LABEL="CPT 3 Procedure CCS"

  CPTCCS4                    LENGTH=4
  LABEL="CPT 4 Procedure CCS"

  CPTCCS5                    LENGTH=4
  LABEL="CPT 5 Procedure CCS"

  CPTCCS6                    LENGTH=4
  LABEL="CPT 6 Procedure CCS"

  CPTCCS7                    LENGTH=4
  LABEL="CPT 7 Procedure CCS"

  CPTCCS8                    LENGTH=4
  LABEL="CPT 8 Procedure CCS"

  CPTCCS9                    LENGTH=4
  LABEL="CPT 9 Procedure CCS"

  CPTCCS10                   LENGTH=4
  LABEL="CPT 10 Procedure CCS"

  CPTCCS11                   LENGTH=4
  LABEL="CPT 11 Procedure CCS"

  CPTCCS12                   LENGTH=4
  LABEL="CPT 12 Procedure CCS"

  CPTCCS13                   LENGTH=4
  LABEL="CPT 13 Procedure CCS"

  CPTCCS14                   LENGTH=4
  LABEL="CPT 14 Procedure CCS"

  CPTCCS15                   LENGTH=4
  LABEL="CPT 15 Procedure CCS"

  CPTCCS16                   LENGTH=4
  LABEL="CPT 16 Procedure CCS"

  CPTCCS17                   LENGTH=4
  LABEL="CPT 17 Procedure CCS"

  CPTCCS18                   LENGTH=4
  LABEL="CPT 18 Procedure CCS"

  CPTCCS19                   LENGTH=4
  LABEL="CPT 19 Procedure CCS"

  CPTCCS20                   LENGTH=4
  LABEL="CPT 20 Procedure CCS"

  CPTCCS21                   LENGTH=4
  LABEL="CPT 21 Procedure CCS"

  CPTCCS22                   LENGTH=4
  LABEL="CPT 22 Procedure CCS"

  CPTCCS23                   LENGTH=4
  LABEL="CPT 23 Procedure CCS"

  CPTCCS24                   LENGTH=4
  LABEL="CPT 24 Procedure CCS"

  CPTCCS25                   LENGTH=4
  LABEL="CPT 25 Procedure CCS"

  CPTCCS26                   LENGTH=4
  LABEL="CPT 26 Procedure CCS"

  CPTCCS27                   LENGTH=4
  LABEL="CPT 27 Procedure CCS"

  CPTCCS28                   LENGTH=4
  LABEL="CPT 28 Procedure CCS"

  CPTCCS29                   LENGTH=4
  LABEL="CPT 29 Procedure CCS"

  CPTCCS30                   LENGTH=4
  LABEL="CPT 30 Procedure CCS"

  CPT1                       LENGTH=$5
  LABEL="CPT Procedure 1"

  CPT2                       LENGTH=$5
  LABEL="CPT Procedure 2"

  CPT3                       LENGTH=$5
  LABEL="CPT Procedure 3"

  CPT4                       LENGTH=$5
  LABEL="CPT Procedure 4"

  CPT5                       LENGTH=$5
  LABEL="CPT Procedure 5"

  CPT6                       LENGTH=$5
  LABEL="CPT Procedure 6"

  CPT7                       LENGTH=$5
  LABEL="CPT Procedure 7"

  CPT8                       LENGTH=$5
  LABEL="CPT Procedure 8"

  CPT9                       LENGTH=$5
  LABEL="CPT Procedure 9"

  CPT10                      LENGTH=$5
  LABEL="CPT Procedure 10"

  CPT11                      LENGTH=$5
  LABEL="CPT Procedure 11"

  CPT12                      LENGTH=$5
  LABEL="CPT Procedure 12"

  CPT13                      LENGTH=$5
  LABEL="CPT Procedure 13"

  CPT14                      LENGTH=$5
  LABEL="CPT Procedure 14"

  CPT15                      LENGTH=$5
  LABEL="CPT Procedure 15"

  CPT16                      LENGTH=$5
  LABEL="CPT Procedure 16"

  CPT17                      LENGTH=$5
  LABEL="CPT Procedure 17"

  CPT18                      LENGTH=$5
  LABEL="CPT Procedure 18"

  CPT19                      LENGTH=$5
  LABEL="CPT Procedure 19"

  CPT20                      LENGTH=$5
  LABEL="CPT Procedure 20"

  CPT21                      LENGTH=$5
  LABEL="CPT Procedure 21"

  CPT22                      LENGTH=$5
  LABEL="CPT Procedure 22"

  CPT23                      LENGTH=$5
  LABEL="CPT Procedure 23"

  CPT24                      LENGTH=$5
  LABEL="CPT Procedure 24"

  CPT25                      LENGTH=$5
  LABEL="CPT Procedure 25"

  CPT26                      LENGTH=$5
  LABEL="CPT Procedure 26"

  CPT27                      LENGTH=$5
  LABEL="CPT Procedure 27"

  CPT28                      LENGTH=$5
  LABEL="CPT Procedure 28"

  CPT29                      LENGTH=$5
  LABEL="CPT Procedure 29"

  CPT30                      LENGTH=$5
  LABEL="CPT Procedure 30"
  ;

/* Read data elements from the CSV file */
INPUT 
      HOSP_NASS                :N5PF.
      KEY_NASS                 :N8PF.
      YEAR                     :N4PF.
      NCPT_NOTINSCOPE          :N3PF.
      CPTCCS1                  :N4PF.
      CPTCCS2                  :N4PF.
      CPTCCS3                  :N4PF.
      CPTCCS4                  :N4PF.
      CPTCCS5                  :N4PF.
      CPTCCS6                  :N4PF.
      CPTCCS7                  :N4PF.
      CPTCCS8                  :N4PF.
      CPTCCS9                  :N4PF.
      CPTCCS10                 :N4PF.
      CPTCCS11                 :N4PF.
      CPTCCS12                 :N4PF.
      CPTCCS13                 :N4PF.
      CPTCCS14                 :N4PF.
      CPTCCS15                 :N4PF.
      CPTCCS16                 :N4PF.
      CPTCCS17                 :N4PF.
      CPTCCS18                 :N4PF.
      CPTCCS19                 :N4PF.
      CPTCCS20                 :N4PF.
      CPTCCS21                 :N4PF.
      CPTCCS22                 :N4PF.
      CPTCCS23                 :N4PF.
      CPTCCS24                 :N4PF.
      CPTCCS25                 :N4PF.
      CPTCCS26                 :N4PF.
      CPTCCS27                 :N4PF.
      CPTCCS28                 :N4PF.
      CPTCCS29                 :N4PF.
      CPTCCS30                 :N4PF.
      CPT1                     :$CHAR5.
      CPT2                     :$CHAR5.
      CPT3                     :$CHAR5.
      CPT4                     :$CHAR5.
      CPT5                     :$CHAR5.
      CPT6                     :$CHAR5.
      CPT7                     :$CHAR5.
      CPT8                     :$CHAR5.
      CPT9                     :$CHAR5.
      CPT10                    :$CHAR5.
      CPT11                    :$CHAR5.
      CPT12                    :$CHAR5.
      CPT13                    :$CHAR5.
      CPT14                    :$CHAR5.
      CPT15                    :$CHAR5.
      CPT16                    :$CHAR5.
      CPT17                    :$CHAR5.
      CPT18                    :$CHAR5.
      CPT19                    :$CHAR5.
      CPT20                    :$CHAR5.
      CPT21                    :$CHAR5.
      CPT22                    :$CHAR5.
      CPT23                    :$CHAR5.
      CPT24                    :$CHAR5.
      CPT25                    :$CHAR5.
      CPT26                    :$CHAR5.
      CPT27                    :$CHAR5.
      CPT28                    :$CHAR5.
      CPT29                    :$CHAR5.
      CPT30                    :$CHAR5.
      ;
RUN;
